<?php

require_once plugin_dir_path( __FILE__ ) . 'class-talque-event-admin-page.php';


/**
 * The talque settings menu in the Admin Panel
 *
 * @package    Talque_Event
 * @subpackage Talque_Event/admin
 * @author     Volker Braun <volker.braun@real-life-interaction.de>
 */
class Talque_Event_Admin_Settings extends Talque_Event_Admin_Page {

    /**
     * The options from register_settings()
     */
    public static $options_list = array(
        'talque-url-speaker',
        'talque-url-talk',
        'talque-theme',
        'talque-maxwidth',
    );
    

    /**
     * Initialize the class and set its properties.
     */
    public function __construct() {
    }

    /**
     * Add the settings talque menu to the Admin Panel
     *
     * @mvc Controller
     */
    public function add_submenu_page() {
        add_submenu_page(
            'talque_event_main',      // Parent slug
            'Talque Settings',        // Page title
            'Settings',               // Menu entry
            self::REQUIRED_CAPABILITY,
            'talque_event_settings',  // Slug
            __CLASS__ . '::page_html'
        );
    }

    public function register_settings() {
        $speaker_args = array(
            'type' => 'string', 
            'default' => NULL,
        );
        register_setting('talque-group-url', 'talque-url-speaker', $speaker_args);
        
        $talk_args = array(
            'type' => 'string', 
            'default' => NULL,
        );
        register_setting('talque-group-url', 'talque-url-talk', $talk_args);
        
        $sponsor_args = array(
            'type' => 'string', 
            'default' => NULL,
        );
        register_setting('talque-group-url', 'talque-url-sponsor', $sponsor_args);
        
        $exhibitor_args = array(
            'type' => 'string', 
            'default' => NULL,
        );
        register_setting('talque-group-url', 'talque-url-exhibitor', $exhibitor_args);
        
        $theme_args = array(
            'type' => 'string', 
            'default' => NULL,
        );
        register_setting( 'talque-group-theme', 'talque-speakerPhoto', $theme_args );
        register_setting( 'talque-group-theme', 'talque-timeTic', $theme_args );
        register_setting( 'talque-group-theme', 'talque-align', $theme_args );
        register_setting( 'talque-group-theme', 'talque-backgroundColor', $theme_args );
        register_setting( 'talque-group-theme', 'talque-depth', $theme_args );
        register_setting( 'talque-group-theme', 'talque-padding', $theme_args );
        register_setting( 'talque-group-theme', 'talque-padding-mobile', $theme_args );
        register_setting( 'talque-group-theme', 'talque-maxwidth', $theme_args );
        register_setting( 'talque-group-theme', 'talque-palette-primary', $theme_args );
        register_setting( 'talque-group-theme', 'talque-palette-accent', $theme_args );
    }
    
    public static function page_html() {
        // check user capabilities
        if (!current_user_can(self::REQUIRED_CAPABILITY)) {
            return;
        }
        require_once dirname(__FILE__) . '/partials/settings-page.php';
    }
        
}


