<?php

/**
 * Provide the main admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://talque.com
 * @since      1.0.0
 *
 * @package    Talque_Event
 * @subpackage Talque_Event/admin/partials
 */
?>


<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>

    <h2>Configuration</h2>

    <form action="options.php" method="post">

        <?php
        // output security fields for the registered setting "talque-event-main"
        settings_fields('talque-group-main');
        ?>

        <div>
            <label for="talque-org-id">Organization ID:</label>
            <input
                id="talque-org-id"
                type="text"
                name="talque-org-id"
                value="<?php echo esc_attr( get_option('talque-org-id') ); ?>" />
        </div>

        <div>
            <label for="talque-backend">Backend server:</label>
            <input
                id="talque-backend"
                type="text"
                name="talque-backend"
                value="<?php echo esc_attr( get_option('talque-backend') ); ?>" />
        </div>
        
        <?php
        // output save settings button
        submit_button('Save');
        ?>
        
    </form>

    <h2>Talque pages</h2>

    <p>
        The talque plugin comes with a set of predefined pages to
        display the content from your event. To add them to your
        Wordpress site menu, start by going to Appearance&rarr;Menus
        in the admin area and edit (or create) your menu.
    </p>

    <p>
        Click on <i>Screen Options</i> on the top right and make sure
        that Talque is selected under Boxes. Then you will see Talque
        as a source for menu entries, below Pages and Posts. The
        Talque options are:
    </p>

    <ul>
        <li>&bull;&nbsp;Sponsors</li>
        <li>&bull;&nbsp;Exhibitors</li>
        <li>&bull;&nbsp;Talk Grid</li>
        <li>&bull;&nbsp;Talk List</li>
        <li>&bull;&nbsp;Speaker Grid</li>
        <li>&bull;&nbsp;Speaker List</li>
    </ul>

    <p>
        Select your desired menu entries and click on <i>Add to Menu</i>.
    </p>

    <h2>Shortcodes</h2>
    
    <p>
        You can use the following shortcodes in blog posts and pages:
    </p>

    <ul>
        <li><tt>[talque-talk-list]</tt> displays vertical list of talks</li>
        <li><tt>[talque-talk-list date="yyyymmdd"]</tt> displays vertical list of talks
            on the given day (e.g. date="20180511" for May 11, 2018).</li>
        <li><tt>[talque-talk-grid]</tt> displays time table of the talks.</li>
        <li><tt>[talque-talk-grid date="yyyymmdd"]</tt> displays time table on the given
            day.</li>
        <li><tt>[talque-speaker-grid backgroundColor="DARK" speakerPhoto="CIRCULAR"]</tt>
            uses white text (appropriate for dark background) and makes them
            speaker photos circular.</li>
        <li><tt>[talque-speaker-list]</tt> displays a vertical list of all speakers</li>
        <li><tt>[talque-speaker-grid]</tt> displays all speakers in a 2-d grid</li>
        <li><tt>[talque-sponsor-grid]</tt> displays a grid of all sponsors</li>
        <li><tt>[talque-exhibitor-grid]</tt> displays a grid of all exhibitors</li>
    </p>

    <p>
        The shortcodes accept optional attributes, which customize the display of your data. Valid settings are as follows.
    </p>

    <h4>Speaker Photo</h4>

    <p>
        Speaker photo determines how the photos are displayed on the speaker
        grid:
    </p>

    <ul>
        <li><tt>speakerPhoto="SQUARE"</tt> photos are square (default)</li>
        <li><tt>speakerPhoto="ROUNDED"</tt> photos have rounded corners</li>
        <li><tt>speakerPhoto="CIRCULAR"</tt> photos are circular</li>
    </ul>

    <h4>Background Color</h4>

    <p>
        The background color adapts fonts for sufficient contrast on top of
        the background set by wordpress page. Note that actually setting the
        background color is the responsibilty of the wordpress page:
    </p>

    <ul>
        <li><tt>backgroundColor="LIGHT"</tt> uses black text (default, appropriate for
            light background)</li>
        <li><tt>backgroundColor="DARK"</tt> uses white text (appropriate for dark
            background)</li>
    </ul>
    
    <h4>Time Tics</h4>

    <p>
        Time tics on the talk grid can be styled as
    </p>

    <ul>
        <li><tt>timeTic="SIMPLE"</tt> just the time (default)</li>
        <li><tt>timeTic="STYLIZED"</tt> display tics in an arrow</li>
    </ul>

    <h4>Depth (3d shadows)</h4>

    <p>
        Where appropriate, the talque plugin can draw a 3d shadow. Options are:
    </p>

    <ul>
        <li><tt>depth="OUTSET"</tt> add a subtle 3d shadow (default)</li>
        <li><tt>depth="FLAT"</tt> no 3d shadows</li>
    </ul>

    <h4>Padding</h4>

    <p>
        With padding you can customize the space around the talque
        content, to prevent it from being too close to other design
        elements on your page. Padding accepts any css padding values:
        Either a single css length, or a pair, or a 4-tuple.
    </p>
    
    <ul>
        <li><tt>padding="1em"</tt> Add one em padding on all four sides</li>
        <li><tt>padding="10px 0"</tt> Add 10px on top/bottom and no padding on the left/right</li>
        <li><tt>padding="10px 20px 30px 40px"</tt> Add the given padding on top, right, bottom, left</li>
    </ul>

    <p>
        On mobile, there is a separate setting for the padding. It
        accepts the same css padding values as above. For example:
    </p>
    
    <ul>
        <li><tt>mobilePadding="1em"</tt> Add one em padding on all four sides</li>
    </ul>

    
    <h4>Max Width</h4>

    <p>
        The max width setting imposes an upper limit on the talque
        content, and can be set to any css length. The actual width
        might be narrower, for example if the wordpress theme or the
        browser size constrains it further. For example:
    </p>
    
    <ul>
        <li><tt>maxwidth="980px"</tt> limit the talque content to 980px</li>
    </ul>

    <h4>Colors</h4>

    <p>
        The primary and accent colors can be set to any html color code, for example:
    </p>

    <ul>
        <li><tt>primary="#6c6906"</tt> use this primary color</li>
        <li><tt>accent="#d9d73f"</tt> use this accent color</li>
    </ul>

    <h2>Further documentation</h2>

    <p>
        Our complete documentation for the talque Wordpress plugin can be found at
        <a href="https://talque.gitbook.io">https://talque.gitbook.io</a>.
    </p>
</div>


