<?php

/**
 * Provide the admin area settings view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://talque.com
 * @since      1.0.0
 *
 * @package    Talque_Event
 * @subpackage Talque_Event/admin/partials
 */
?>


<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>

    <h2>Custom URLs</h2>

    <p>
        You can create additional custom URLs for speakers, talks,
        sponsors, and exhibitors. By default, the generated page where
        a single entity (speaker / talk / sponsor / exhibitor) is
        shown uses a query parameter and internal id to identify the
        entity. Here you can alternatively define a custom url path
        where the page should be listed with a human-readable name
        derived from the speaker / sponsor / exhibitor name or talk
        title.  Custom URL structures can improve the aesthetics,
        usability, and forward-compatibility of your links. Note:
        Custom URLs only work if the Wordpress rewrite engine is
        active, that is, Settings&rarr;Permalinks&rarr;Common Settings
        must be set to something else than <i>Plain</i>.
    </p>
 
    <form action="options.php" method="post">

        <?php
        // output security fields for the registered setting "talque-group-url"
        settings_fields('talque-group-url');
        ?>

        <div>
            <label for="talque-url-speaker">Speaker URL:</label>
            <span><?php echo get_home_url() ?>/</span>
            <input
                id="talque-url-speaker"
                type="text"
                name="talque-url-speaker"
                value="<?php echo esc_attr( get_option('talque-url-speaker') ); ?>" />
            <span>/first_last</span>
        </div>

        <div>
            <label for="talque-url-talk">Talk URL:</label>
            <span><?php echo get_home_url() ?>/</span>
            <input
                id="talque-url-talk"
                type="text"
                name="talque-url-talk"
                value="<?php echo esc_attr( get_option('talque-url-talk') ); ?>" />
            <span>/title_of_talk</span>
        </div>
        
        <div>
            <label for="talque-url-sponsor">Sponsor URL:</label>
            <span><?php echo get_home_url() ?>/</span>
            <input
                id="talque-url-sponsor"
                type="text"
                name="talque-url-sponsor"
                value="<?php echo esc_attr( get_option('talque-url-sponsor') ); ?>" />
            <span>/name_of_sponsor</span>
        </div>
        
        <div>
            <label for="talque-url-exhibitor">Exhibitor URL:</label>
            <span><?php echo get_home_url() ?>/</span>
            <input
                id="talque-url-exhibitor"
                type="text"
                name="talque-url-exhibitor"
                value="<?php echo esc_attr( get_option('talque-url-exhibitor') ); ?>" />
            <span>/name_of_exhibitor</span>
        </div>
        
        <?php
        // output save settings button
        submit_button('Save');
        ?>

    </form>

    <h2>Theme</h2>

    <p>
        Here you can customize the appearance of the talque
        content. This defines the default theme, it can be overriden
        in some of the wordpress shortcodes.
    </p>
    
    <form action="options.php" method="post">

        <?php
        // output security fields for the registered setting "talque-theme"
        settings_fields('talque-group-theme');
        ?>
        
        <h4>Speaker photo style</h4>
        
        <p>
            Determines how the speaker photo is cropped, if at all. Values are 
        </p>

        <div>
            <label for="talque-speakerPhoto">Speaker photo:</label>
            <input
                id="talque-speakerPhoto"
                type="text"
                name="talque-speakerPhoto"
                value="<?php echo esc_attr( get_option('talque-speakerPhoto') ); ?>" />
        </div>

        <div>
            <label for="talque-timeTic">Time tic:</label>
            <input
                id="talque-timeTic"
                type="text"
                name="talque-timeTic"
                value="<?php echo esc_attr( get_option('talque-timeTic') ); ?>" />
        </div>

        <div>
            <label for="talque-align">Align:</label>
            <input
                id="talque-align"
                type="text"
                name="talque-align"
                value="<?php echo esc_attr( get_option('talque-align') ); ?>" />
        </div>

        <div>
            <label for="talque-backgroundColor">Background color:</label>
            <input
                id="talque-backgroundColor"
                type="text"
                name="talque-backgroundColor"
                value="<?php echo esc_attr( get_option('talque-backgroundColor') ); ?>" />
        </div>

        <div>
            <label for="talque-depth">Depth:</label>
            <input
                id="talque-depth"
                type="text"
                name="talque-depth"
                value="<?php echo esc_attr( get_option('talque-depth') ); ?>" />
        </div>

        <div>
            <label for="talque-padding">Padding (on desktop):</label>
            <input
                id="talque-padding"
                type="text"
                name="talque-padding"
                value="<?php echo esc_attr( get_option('talque-padding') ); ?>" />
        </div>

        <div>
            <label for="talque-padding-mobile">Padding (on mobile):</label>
            <input
                id="talque-padding-mobile"
                type="text"
                name="talque-padding-mobile"
                value="<?php echo esc_attr( get_option('talque-padding-mobile') ); ?>" />
        </div>

        <div>
            <label for="talque-maxwidth">Max width:</label>
            <input
                id="talque-maxwidth"
                type="text"
                name="talque-maxwidth"
                value="<?php echo esc_attr( get_option('talque-maxwidth') ); ?>" />
        </div>

        <div>
            <label for="talque-palette-primary">Primary color:</label>
            <input
                id="talque-palette-primary"
                type="text"
                name="talque-palette-primary"
                value="<?php echo esc_attr( get_option('talque-palette-primary') ); ?>" />
        </div>

        <div>
            <label for="talque-palette-accent">Accent color:</label>
            <input
                id="talque-palette-accent"
                type="text"
                name="talque-palette-accent"
                value="<?php echo esc_attr( get_option('talque-palette-accent') ); ?>" />
        </div>

        <?php
        // output save settings button
        submit_button('Save');
        ?>

    </form>
    
</div>


